@@ -423,7 +423,8 @@ ddl<-NULL
 ddl<-
 solve.QP(Dmat=diag(1,l),dvec= z, Amat=t(DD), meq=0, factorized=FALSE)
 
-if (is.null(ddl)){next}
+if (is.null(ddl)){ pw<-matrix(0,ur+1,1)}
+else{
 #dd<-ddl$solution
 #dd0<-ddl$unconstrainted.solution
 d<-NULL
@@ -444,7 +445,7 @@ pw<-matrix(0,ur+1,1)
 #print( "failed")
 
 }
-
+}
 pw
 }
 
